@@ -12,12 +12,8 @@ function _aws_cdk_aws_m2_CfnApplicationProps(p) {
 }
 function _aws_cdk_aws_m2_CfnApplication(p) {
 }
-function _aws_cdk_aws_m2_CfnApplication_ContentProperty(p) {
-}
 function _aws_cdk_aws_m2_CfnApplication_DefinitionProperty(p) {
 }
-function _aws_cdk_aws_m2_CfnApplication_S3LocationProperty(p) {
-}
 function _aws_cdk_aws_m2_CfnEnvironmentProps(p) {
 }
 function _aws_cdk_aws_m2_CfnEnvironment(p) {
@@ -66,4 +62,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_m2_CfnApplicationProps, _aws_cdk_aws_m2_CfnApplication, _aws_cdk_aws_m2_CfnApplication_ContentProperty, _aws_cdk_aws_m2_CfnApplication_DefinitionProperty, _aws_cdk_aws_m2_CfnApplication_S3LocationProperty, _aws_cdk_aws_m2_CfnEnvironmentProps, _aws_cdk_aws_m2_CfnEnvironment, _aws_cdk_aws_m2_CfnEnvironment_EfsStorageConfigurationProperty, _aws_cdk_aws_m2_CfnEnvironment_FsxStorageConfigurationProperty, _aws_cdk_aws_m2_CfnEnvironment_HighAvailabilityConfigProperty, _aws_cdk_aws_m2_CfnEnvironment_StorageConfigurationProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_m2_CfnApplicationProps, _aws_cdk_aws_m2_CfnApplication, _aws_cdk_aws_m2_CfnApplication_DefinitionProperty, _aws_cdk_aws_m2_CfnEnvironmentProps, _aws_cdk_aws_m2_CfnEnvironment, _aws_cdk_aws_m2_CfnEnvironment_EfsStorageConfigurationProperty, _aws_cdk_aws_m2_CfnEnvironment_FsxStorageConfigurationProperty, _aws_cdk_aws_m2_CfnEnvironment_HighAvailabilityConfigProperty, _aws_cdk_aws_m2_CfnEnvironment_StorageConfigurationProperty };
